pub struct CsbEntry {
pub fighter_kind: Hash40,
pub sound_table: Vec<Hash40>,
}Expand description
A collection of common sound labels for a particular fighter.
Fields
fighter_kind: Hash40Hashed name of the fighter.
sound_table: Vec<Hash40>Collection of common sound labels associated with the fighter.